@@ -1,5 +1,6 @@
 from chinstrap.originations import getContract
 
+
 def deploy(chinstrapState, network, accounts):
     # if there are . in the name, please replace them with _
     # For example, to access FA1.2 contract, we use FA1_2
@@ -7,14 +8,13 @@ def deploy(chinstrapState, network, accounts):
 
     initial_storage = contract.storage.encode(
         {
-            'administrator': accounts[0].key.public_key_hash(), 
-            'balances': {}, 
-            'metadata': {}, 
-            'paused': False, 
-            'token_metadata': {
-            }, 
-            'totalSupply': 0
+            "administrator": accounts[0].key.public_key_hash(),
+            "balances": {},
+            "metadata": {},
+            "paused": False,
+            "token_metadata": {},
+            "totalSupply": 0,
         }
     )
-    
+
     return initial_storage, contract
